@@ -405,3 +405,36 @@ fractaltree <- function(npoints = 1e5) {
 
   return(x)
 }
+
+
+################################################################################
+################################################################################
+###
+###  auxiliar functions for xmaspeace
+###
+################################################################################
+################################################################################
+
+# function to detect point inside/outside the tree:
+point_in_polygon <- function(x, y, poly.x, poly.y) {
+  n <- length(poly.x)
+  inside <- FALSE
+  poly.x <- c(poly.x, poly.x[1])
+  poly.y <- c(poly.y, poly.y[1])
+
+  for (i in 1:n) {
+    xi <- poly.x[i]
+    yi <- poly.y[i]
+    xj <- poly.x[i + 1]
+    yj <- poly.y[i + 1]
+
+    intersect <- ((yi > y) != (yj > y)) &&
+      (x < (xj - xi) * (y - yi) / (yj - yi) + xi)
+
+    if (intersect) {
+      inside <- !inside
+    }
+  }
+  return(inside)
+}
+
